@@ -4,10 +4,12 @@ use 5.010001;
 use strict;
 use warnings;
 
+use Capture::Tiny 'capture_stderr';
+
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2022-09-14'; # DATE
 our $DIST = 'App-VitaminUtils'; # DIST
-our $VERSION = '0.005'; # VERSION
+our $VERSION = '0.006'; # VERSION
 
 our %SPEC;
 
@@ -301,11 +303,13 @@ _
 sub convert_vitamin_d_unit {
     require Physics::Unit;
 
-    Physics::Unit::InitUnit(
-        ['mcg'], '0.001 mg',
-        ['ng'],  '0.000001 mg',
-        ['IU', 'iu'], '0.025 microgram',
-    );
+    capture_stderr {
+        Physics::Unit::InitUnit(
+            ['g'], 'gram', # emits warning 'already defined' warning, but '3g' won't work if we don't add this
+            ['mcg'], '0.001 mg',
+            ['IU', 'iu'], '0.025 microgram',
+        );
+    }; # silence warning
 
     my %args = @_;
     my $quantity = Physics::Unit->new($args{quantity});
@@ -416,7 +420,7 @@ App::VitaminUtils - Utilities related to vitamins
 
 =head1 VERSION
 
-This document describes version 0.005 of App::VitaminUtils (from Perl distribution App-VitaminUtils), released on 2022-09-14.
+This document describes version 0.006 of App::VitaminUtils (from Perl distribution App-VitaminUtils), released on 2022-09-14.
 
 =head1 DESCRIPTION
 
